==> openGion6.7.3.0_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2017/01/05 15:19:19                                            */
/****************************************************************************/

CREATE TABLE GE20 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        varchar           (  500 )                  NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     varchar           (   50 )                  NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        varchar           ( 4000 )                                      /*  50 設定値   */
 , KBSET        varchar           (    1 )      DEFAULT 0   NOT NULL            /*  60 設定区分 */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者   */
);

==> openGion6.8.4.1_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE20 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        varchar           ( 2000 )                  NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     varchar           (   50 )                  NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        varchar           ( 4000 )                                      /*  50 設定値   */
 , KBSET        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  60 設定区分 */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者   */
);
